using System;
using System.Collections.Generic;
using System.Globalization;
using System.Text;

namespace BenLincoln.Utility
{
    public class FormatConverter
    {
        // this is kind of a hack, but I couldn't think of a genuinely better way to do it
        public static float StringToFloat(string value)
        {
            float result = 0.0f;

            // first, try the culture-invariant method, because it's what people should be using
            try
            {
                result = float.Parse(value, NumberFormatInfo.InvariantInfo);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            // second, try the default for .NET on the system
            try
            {
                result = float.Parse(value);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            // third, try the US-specific method, because it's basically the same as the culture-invariant method
            try
            {
                CultureInfo ciUS = new CultureInfo("en-US");
                result = float.Parse(value, ciUS);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            // try the four options that are available by default in .NET
            try
            {
                result = float.Parse(value, System.Globalization.CultureInfo.CurrentCulture);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            try
            {
                result = float.Parse(value, System.Globalization.CultureInfo.CurrentUICulture);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            try
            {
                result = float.Parse(value, System.Globalization.CultureInfo.InstalledUICulture);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            throw new FormatException("Could not convert the string '" + value + "' to a floating-point number.");
        }

        public static int StringToInt(string value)
        {
            int result = 0;

            // first, try the culture-invariant method, because it's what people should be using
            try
            {
                result = int.Parse(value, NumberFormatInfo.InvariantInfo);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            // second, try the default for .NET on the system
            try
            {
                result = int.Parse(value);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            // third, try the US-specific method, because it's basically the same as the culture-invariant method
            try
            {
                CultureInfo ciUS = new CultureInfo("en-US");
                result = int.Parse(value, ciUS);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            // try the four options that are available by default in .NET
            try
            {
                result = int.Parse(value, System.Globalization.CultureInfo.CurrentCulture);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            try
            {
                result = int.Parse(value, System.Globalization.CultureInfo.CurrentUICulture);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            try
            {
                result = int.Parse(value, System.Globalization.CultureInfo.InstalledUICulture);
                return result;
            }
            catch (Exception ex)
            {
                // do nothing - proceed to the next method
            }

            throw new FormatException("Could not convert the string '" + value + "' to an integer.");
        }

        public static string FloatToString(float value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string DoubleToString(double value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string ShortToString(short value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string IntToString(int value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string LongToString(long value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string UShortToString(ushort value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string UIntToString(uint value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }

        public static string ULongToString(ulong value)
        {
            return value.ToString(NumberFormatInfo.InvariantInfo);
        }
    }
}
